{
    "$graph": [
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "label": "output of infernal's cmsearch",
                    "id": "#5S-from-tablehits.cwl/table_hits"
                }
            ],
            "steps": [
                {
                    "run": "#extract-coords-from-cmsearch.cwl",
                    "in": [
                        {
                            "source": "#5S-from-tablehits.cwl/grep/5Ss",
                            "id": "#5S-from-tablehits.cwl/extract_5S_coords/infernal_matches"
                        }
                    ],
                    "out": [
                        "#5S-from-tablehits.cwl/extract_5S_coords/matched_seqs_with_coords"
                    ],
                    "id": "#5S-from-tablehits.cwl/extract_5S_coords"
                },
                {
                    "run": "#pull-5Ss.cwl",
                    "in": [
                        {
                            "source": "#5S-from-tablehits.cwl/table_hits",
                            "id": "#5S-from-tablehits.cwl/grep/hits"
                        }
                    ],
                    "out": [
                        "#5S-from-tablehits.cwl/grep/5Ss"
                    ],
                    "id": "#5S-from-tablehits.cwl/grep"
                }
            ],
            "id": "#5S-from-tablehits.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#5S-from-tablehits.cwl/extract_5S_coords/matched_seqs_with_coords",
                    "id": "#5S-from-tablehits.cwl/5S_coordinates"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "FragGeneScan: find (fragmented) genes in short reads",
            "doc": "FragGeneScan is an application for finding (fragmented) genes in short\nreads. It can also be applied to predict prokaryotic genes in incomplete\nassemblies or complete genomes.\n\nFragGeneScan was first released through omics website (http://omics.informatics.indiana.edu/FragGeneScan/)\nin March 2010, where you can find its old releases. FragGeneScan migrated to SourceForge in October, 2013\n(https://sourceforge.net/projects/fraggenescan/).\n\nVersion 1.20 can be downloaded here:\nhttps://sourceforge.net/projects/fraggenescan/files/\n",
            "baseCommand": "FragGeneScan",
            "requirements": [
                {
                    "listing": [
                        {
                            "entryname": "train/model",
                            "entry": "$(inputs.model.main)"
                        },
                        {
                            "entryname": "train/gene",
                            "entry": "$(inputs.model.prob_forward)"
                        },
                        {
                            "entryname": "train/rgene",
                            "entry": "$(inputs.model.prob_backward)"
                        },
                        {
                            "entryname": "train/noncoding",
                            "entry": "$(inputs.model.prob_noncoding)"
                        },
                        {
                            "entryname": "train/start",
                            "entry": "$(inputs.model.prob_start)"
                        },
                        {
                            "entryname": "train/stop",
                            "entry": "$(inputs.model.prob_stop)"
                        },
                        {
                            "entryname": "train/start1",
                            "entry": "$(inputs.model.prob_start1)"
                        },
                        {
                            "entryname": "train/stop1",
                            "entry": "$(inputs.model.prob_stop1)"
                        },
                        {
                            "entryname": "train/pwm",
                            "entry": "$(inputs.model.pwm_dist)"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                },
                {
                    "types": [
                        {
                            "type": "record",
                            "name": "#FragGeneScan-model.yaml/model",
                            "fields": [
                                {
                                    "name": "#FragGeneScan-model.yaml/model/main",
                                    "type": "File"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_forward",
                                    "type": "File",
                                    "label": "Forward probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_backward",
                                    "type": "File",
                                    "label": "Backward probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_noncoding",
                                    "type": "File",
                                    "label": "Noncoding probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_start",
                                    "type": "File",
                                    "label": "Start probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_stop",
                                    "type": "File",
                                    "label": "Stop probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_start1",
                                    "type": "File",
                                    "label": "Start1 probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_stop1",
                                    "type": "File",
                                    "label": "Stop1 probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/pwm_dist",
                                    "type": "File",
                                    "label": "pwm distribution"
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_011929"
                            ],
                            "version": [
                                "1.20"
                            ],
                            "package": "fraggenescan"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "True if the sequence file has complete genomic sequences\nFalse if the sequence file has short sequence reads\n",
                    "type": "boolean",
                    "inputBinding": {
                        "valueFrom": "${ if (self) {\n     return [ \"-w\", \"1\" ];\n   } else {\n     return [ \"-w\", \"0\" ];\n   }\n }\n"
                    },
                    "id": "#FragGeneScan1_20.cwl/completeSeq"
                },
                {
                    "type": "#FragGeneScan-model.yaml/model",
                    "id": "#FragGeneScan1_20.cwl/model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#FragGeneScan1_20.cwl/sequence"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#FragGeneScan1_20.cwl/threadNumber"
                }
            ],
            "arguments": [
                {
                    "prefix": "-o",
                    "valueFrom": "$(runtime.outdir)/predicted_cds"
                },
                {
                    "prefix": "-t",
                    "valueFrom": "model"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "predicted_cds.faa"
                    },
                    "id": "#FragGeneScan1_20.cwl/predicted_CDS_aa"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "predicted_cds.ffn"
                    },
                    "id": "#FragGeneScan1_20.cwl/predicted_CDS_nuc"
                }
            ],
            "id": "#FragGeneScan1_20.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "InterProScan: protein sequence classifier",
            "doc": "Version 5.21-60 can be downloaded here:\nhttps://github.com/ebi-pf-team/interproscan/wiki/HowToDownload\n\nDocumentation on how to run InterProScan 5 can be found here:\nhttps://github.com/ebi-pf-team/interproscan/wiki/HowToRun\n",
            "requirements": [
                {
                    "ramMin": 10240,
                    "coresMin": 3,
                    "class": "ResourceRequirement"
                },
                {
                    "types": [
                        {
                            "type": "enum",
                            "name": "#InterProScan-apps.yaml/apps",
                            "symbols": [
                                "#InterProScan-apps.yaml/apps/TIGRFAM",
                                "#InterProScan-apps.yaml/apps/SFLD",
                                "#InterProScan-apps.yaml/apps/SUPERFAMILY",
                                "#InterProScan-apps.yaml/apps/Gene3D",
                                "#InterProScan-apps.yaml/apps/Hamap",
                                "#InterProScan-apps.yaml/apps/Coils",
                                "#InterProScan-apps.yaml/apps/ProSiteProfiles",
                                "#InterProScan-apps.yaml/apps/SMART",
                                "#InterProScan-apps.yaml/apps/CDD",
                                "#InterProScan-apps.yaml/apps/PRINTS",
                                "#InterProScan-apps.yaml/apps/PIRSF",
                                "#InterProScan-apps.yaml/apps/ProSitePatterns",
                                "#InterProScan-apps.yaml/apps/Pfam",
                                "#InterProScan-apps.yaml/apps/ProDom",
                                "#InterProScan-apps.yaml/apps/MobiDBLite"
                            ]
                        },
                        {
                            "type": "enum",
                            "name": "#InterProScan-protein_formats.yaml/protein_formats",
                            "symbols": [
                                "#InterProScan-protein_formats.yaml/protein_formats/TSV",
                                "#InterProScan-protein_formats.yaml/protein_formats/XML",
                                "#InterProScan-protein_formats.yaml/protein_formats/GFF3"
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005829"
                            ],
                            "version": [
                                "5.21-60"
                            ],
                            "package": "interproscan"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "#InterProScan-apps.yaml/apps"
                        }
                    ],
                    "inputBinding": {
                        "itemSeparator": ",",
                        "prefix": "--applications"
                    },
                    "id": "#InterProScan5.21-60.cwl/applications"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#InterProScan5.21-60.cwl/proteinFile"
                }
            ],
            "baseCommand": "interproscan.sh",
            "arguments": [
                {
                    "valueFrom": "$(inputs.proteinFile.nameroot).i5_annotations",
                    "prefix": "--outfile"
                },
                {
                    "valueFrom": "TSV",
                    "prefix": "--formats"
                },
                "--disable-precalc",
                "--goterms",
                "--pathways",
                {
                    "valueFrom": "$(runtime.tmpdir)",
                    "prefix": "--tempdir"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.proteinFile.nameroot).i5_annotations"
                    },
                    "id": "#InterProScan5.21-60.cwl/i5Annotations"
                }
            ],
            "id": "#InterProScan5.21-60.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "label": "output of infernal's cmsearch",
                    "id": "#LSU-from-tablehits.cwl/table_hits"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#LSU-from-tablehits.cwl/extract_lsu_coords/matched_seqs_with_coords",
                    "id": "#LSU-from-tablehits.cwl/LSU_coordinates"
                }
            ],
            "steps": [
                {
                    "run": "#extract-coords-from-cmsearch.cwl",
                    "in": [
                        {
                            "source": "#LSU-from-tablehits.cwl/grep/LSUs",
                            "id": "#LSU-from-tablehits.cwl/extract_lsu_coords/infernal_matches"
                        }
                    ],
                    "out": [
                        "#LSU-from-tablehits.cwl/extract_lsu_coords/matched_seqs_with_coords"
                    ],
                    "id": "#LSU-from-tablehits.cwl/extract_lsu_coords"
                },
                {
                    "run": "#pull-LSUs.cwl",
                    "in": [
                        {
                            "source": "#LSU-from-tablehits.cwl/table_hits",
                            "id": "#LSU-from-tablehits.cwl/grep/hits"
                        }
                    ],
                    "out": [
                        "#LSU-from-tablehits.cwl/grep/LSUs"
                    ],
                    "id": "#LSU-from-tablehits.cwl/grep"
                }
            ],
            "id": "#LSU-from-tablehits.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "label": "output of infernal's cmsearch",
                    "id": "#SSU-from-tablehits.cwl/table_hits"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#SSU-from-tablehits.cwl/extract_coords/matched_seqs_with_coords",
                    "id": "#SSU-from-tablehits.cwl/SSU_coordinates"
                }
            ],
            "steps": [
                {
                    "run": "#extract-coords-from-cmsearch.cwl",
                    "in": [
                        {
                            "source": "#SSU-from-tablehits.cwl/grep/SSUs",
                            "id": "#SSU-from-tablehits.cwl/extract_coords/infernal_matches"
                        }
                    ],
                    "out": [
                        "#SSU-from-tablehits.cwl/extract_coords/matched_seqs_with_coords"
                    ],
                    "id": "#SSU-from-tablehits.cwl/extract_coords"
                },
                {
                    "run": "#pull-SSUs.cwl",
                    "in": [
                        {
                            "source": "#SSU-from-tablehits.cwl/table_hits",
                            "id": "#SSU-from-tablehits.cwl/grep/hits"
                        }
                    ],
                    "out": [
                        "#SSU-from-tablehits.cwl/grep/SSUs"
                    ],
                    "id": "#SSU-from-tablehits.cwl/grep"
                }
            ],
            "id": "#SSU-from-tablehits.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                },
                {
                    "types": [
                        {
                            "type": "enum",
                            "name": "#biom-convert-table.yaml/table_type",
                            "label": "The type of the table to produce",
                            "symbols": [
                                "#biom-convert-table.yaml/table_type/OTUtable",
                                "#biom-convert-table.yaml/table_type/Pathwaytable",
                                "#biom-convert-table.yaml/table_type/Functiontable",
                                "#biom-convert-table.yaml/table_type/Orthologtable",
                                "#biom-convert-table.yaml/table_type/Genetable",
                                "#biom-convert-table.yaml/table_type/Metabolitetable",
                                "#biom-convert-table.yaml/table_type/Taxontable",
                                "#biom-convert-table.yaml/table_type/Table"
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://doi.org/10.1186/2047-217X-1-7"
                            ],
                            "version": [
                                "2.1.6"
                            ],
                            "package": "biom-format"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3746",
                    "inputBinding": {
                        "prefix": "--input-fp"
                    },
                    "id": "#biom-convert.cwl/biom"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as HDF5-formatted table.",
                    "inputBinding": {
                        "prefix": "--to-hdf5"
                    },
                    "id": "#biom-convert.cwl/hdf5"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "The observation metadata to include from the input BIOM table file when\ncreating a tsv table file. By default no observation metadata will be\nincluded.\n",
                    "inputBinding": {
                        "prefix": "--header-key"
                    },
                    "id": "#biom-convert.cwl/header_key"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as JSON-formatted table.",
                    "inputBinding": {
                        "prefix": "--to-json"
                    },
                    "id": "#biom-convert.cwl/json"
                },
                {
                    "type": [
                        "null",
                        "#biom-convert-table.yaml/table_type"
                    ],
                    "inputBinding": {
                        "prefix": "--table-type"
                    },
                    "id": "#biom-convert.cwl/table_type"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as TSV-formatted (classic) table.",
                    "inputBinding": {
                        "prefix": "--to-tsv"
                    },
                    "id": "#biom-convert.cwl/tsv"
                }
            ],
            "baseCommand": [
                "biom",
                "convert"
            ],
            "arguments": [
                {
                    "valueFrom": "${ var ext = \"\";\n   if (inputs.json) { ext = \".json\"; }\n   if (inputs.hdf5) { ext = \".hdf5\"; }\n   if (inputs.tsv) { ext = \".tsv\"; }\n   return inputs.biom.nameroot + ext; }\n",
                    "prefix": "--output-fp"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.biom.nameroot)*"
                    },
                    "id": "#biom-convert.cwl/result"
                }
            ],
            "id": "#biom-convert.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "remove lower scoring overlaps from cmsearch --tblout files.",
            "doc": "https://github.com/nawrockie/cmsearch_tblout_deoverlap/blob/master/00README.txt",
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://github.com/nawrockie/cmsearch_tblout_deoverlap"
                            ],
                            "package": "cmsearch_tblout_deoverlap"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "requirements": [
                {
                    "envDef": [
                        {
                            "envValue": "C",
                            "envName": "LC_ALL"
                        }
                    ],
                    "class": "EnvVarRequirement"
                },
                {
                    "listing": [
                        "$(inputs.cmsearch_matches)"
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "label": "clan information on the models provided",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--clanin"
                    },
                    "doc": "Not all models provided need to be a member of a clan",
                    "id": "#cmsearch-deoverlap.cwl/clan_information"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "valueFrom": "$(self.basename)"
                    },
                    "id": "#cmsearch-deoverlap.cwl/cmsearch_matches"
                }
            ],
            "baseCommand": "cmsearch-deoverlap.pl",
            "outputs": [
                {
                    "label": "target hits table, format 2",
                    "doc": "http://eddylab.org/infernal/Userguide.pdf#page=60",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.deoverlapped"
                    },
                    "id": "#cmsearch-deoverlap.cwl/deoverlapped_matches"
                }
            ],
            "id": "#cmsearch-deoverlap.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "streamable": true,
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#concatenate.cwl/files"
                }
            ],
            "baseCommand": "cat",
            "stdout": "result",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "result",
                        "outputEval": "${ self[0].format = inputs.files[0].format;\n   return self; }\n"
                    },
                    "id": "#concatenate.cwl/result"
                }
            ],
            "id": "#concatenate.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "categorise sequences",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69"
                            ],
                            "package": "biopython"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "format": "https://www.iana.org/assignments/media-types/application/json",
                    "id": "#create_categorisations.cwl/cds_idset"
                },
                {
                    "type": "File",
                    "streamable": true,
                    "format": "https://www.iana.org/assignments/media-types/application/json",
                    "id": "#create_categorisations.cwl/ipr_idset"
                },
                {
                    "type": "File",
                    "streamable": true,
                    "format": "http://edamontology.org/format_1929",
                    "id": "#create_categorisations.cwl/seqs"
                }
            ],
            "baseCommand": "python",
            "arguments": [
                {
                    "prefix": "-c",
                    "valueFrom": "import json\nfrom Bio import SeqIO\nipr_idset = frozenset(json.load(open(\"$(inputs.ipr_idset.path)\", \"r\")))\ncds_idset = frozenset(json.load(open(\"$(inputs.cds_idset.path)\", \"r\")))\nipr_output = open(\"interproscan.fasta\", \"w\")\ncds_output = open(\"pCDS.fasta\", \"w\")\nnof_output = open(\"noFunction.fasta\", \"w\")\nfor seq in SeqIO.parse(\"$(inputs.seqs.path)\", \"fasta\"):\n    ipr_seen = False\n    if seq.name in ipr_idset:\n        ipr_output.write(str(\">\" + seq.name + \"\\\\n\" + seq.seq + \"\\\\n\"))\n        ipr_seen = True\n    if seq.name in cds_idset:\n        cds_output.write(str(\">\" + seq.name + \"\\\\n\" + seq.seq + \"\\\\n\"))\n        if not ipr_seen:\n             nof_output.write(str(\">\" + seq.name + \"\\\\n\" + seq.seq + \"\\\\n\"))\n"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "streamable": true,
                    "outputBinding": {
                        "glob": "interproscan.fasta"
                    },
                    "id": "#create_categorisations.cwl/interproscan"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "streamable": true,
                    "outputBinding": {
                        "glob": "noFunction.fasta"
                    },
                    "id": "#create_categorisations.cwl/no_functions_seqs"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "streamable": true,
                    "outputBinding": {
                        "glob": "pCDS.fasta"
                    },
                    "id": "#create_categorisations.cwl/pCDS_seqs"
                }
            ],
            "id": "#create_categorisations.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "drop short seqs",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69"
                            ],
                            "package": "biopython"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "label": "discard if number of bases is less than this amount",
                    "id": "#discard_short_seqs.cwl/minimum_length"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#discard_short_seqs.cwl/sequences"
                }
            ],
            "baseCommand": [
                "python"
            ],
            "arguments": [
                {
                    "valueFrom": "from Bio import SeqIO\ninput_seq_iterator = SeqIO.parse(\"$(inputs.sequences.path)\", \"fasta\")\nshort_seq_iterator = (record for record in input_seq_iterator if len(record.seq) >= $(inputs.minimum_length))\nSeqIO.write(short_seq_iterator, \"$(inputs.sequences.basename).filtered.fasta\", \"fasta\")\n",
                    "prefix": "-c"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.basename).filtered.fasta"
                    },
                    "format": "http://edamontology.org/format_1929",
                    "id": "#discard_short_seqs.cwl/filtered_sequences"
                }
            ],
            "id": "#discard_short_seqs.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "normalize to fasta",
            "doc": "normalizes input sequeces to FASTA with fixed number of sequence characters\nper line using esl-reformat from https://github.com/EddyRivasLab/easel\n",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                },
                {
                    "types": [
                        {
                            "type": "record",
                            "name": "#esl-reformat-replace.yaml/replace",
                            "label": "sequence token replacement",
                            "fields": [
                                {
                                    "name": "#esl-reformat-replace.yaml/replace/find",
                                    "type": "string",
                                    "label": null,
                                    "doc": "Must be equal length with \"replace\". Each character from the input file\nwill be replaced by its counterpart (at the same position) from \"replace\"\n"
                                },
                                {
                                    "name": "#esl-reformat-replace.yaml/replace/replace",
                                    "type": "string",
                                    "label": null,
                                    "doc": "must be equal length with \"find\""
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "package": "easel"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "#esl-reformat-replace.yaml/replace"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--replace",
                        "valueFrom": "$(self.find):$(self.replace)"
                    },
                    "id": "#esl-reformat.cwl/replace"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "format": [
                        "http://edamontology.org/format_1929"
                    ],
                    "id": "#esl-reformat.cwl/sequences"
                }
            ],
            "baseCommand": [
                "esl-reformat"
            ],
            "arguments": [
                {
                    "valueFrom": "fasta",
                    "position": 2
                }
            ],
            "stdout": "reformatted_sequences",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-reformat.cwl/reformatted_sequences",
                    "outputBinding": {
                        "glob": "reformatted_sequences"
                    }
                }
            ],
            "id": "#esl-reformat.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "index a sequence file for use by esl-sfetch",
            "doc": "https://github.com/EddyRivasLab/easel",
            "requirements": [
                {
                    "listing": [
                        "$(inputs.sequences)"
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "package": "easel"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "valueFrom": "$(self.basename)"
                    },
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-sfetch-index.cwl/sequences"
                }
            ],
            "baseCommand": [
                "esl-sfetch",
                "--index"
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.basename)"
                    },
                    "id": "#esl-sfetch-index.cwl/sequences_with_index"
                }
            ],
            "id": "#esl-sfetch-index.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "extract by names from an indexed sequence file",
            "doc": "https://github.com/EddyRivasLab/easel",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "package": "easel"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "label": "sequence file indexed by esl-sfetch-index",
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "inputBinding": {
                        "prefix": "-f",
                        "position": 1
                    },
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-sfetch-manyseqs.cwl/indexed_sequences"
                },
                {
                    "type": "File",
                    "label": "sequence names to retrieve, one per line",
                    "streamable": true,
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#esl-sfetch-manyseqs.cwl/names"
                },
                {
                    "doc": "GDF format: <newname> <from> <to> <source seqname>\nspace/tabdelimited\n",
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "-C"
                    },
                    "id": "#esl-sfetch-manyseqs.cwl/names_contain_subseq_coords"
                }
            ],
            "baseCommand": [
                "esl-sfetch"
            ],
            "stdout": "$(inputs.indexed_sequences.nameroot)_$(inputs.names.nameroot).fasta",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-sfetch-manyseqs.cwl/sequences",
                    "outputBinding": {
                        "glob": "$(inputs.indexed_sequences.nameroot)_$(inputs.names.nameroot).fasta"
                    }
                }
            ],
            "id": "#esl-sfetch-manyseqs.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "label": "output from infernal cmsearch",
                    "type": "File",
                    "streamable": true,
                    "id": "#extract-coords-from-cmsearch.cwl/infernal_matches"
                }
            ],
            "baseCommand": "awk",
            "stdout": "matched_seqs_with_coords",
            "arguments": [
                "{print $1\"-\"$3\"/\"$8\"-\"$9\" \"$8\" \"$9\" \"$1}",
                "$(inputs.infernal_matches.path)"
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#extract-coords-from-cmsearch.cwl/matched_seqs_with_coords",
                    "outputBinding": {
                        "glob": "matched_seqs_with_coords"
                    }
                }
            ],
            "doc": "The awk script takes the output of Infernal's cmsearch so-called fmt=1 mode\nand makes it suitable for use by esl-sfetch, a sequence selector\n\nReading the user's guide for Infernal, Version 1.1.2; July 2016\nhttp://eddylab.org/infernal/Userguide.pdf#page=60 we see that\nthe relevant fields in the cmsearch output are:\n(column number: explanation)\n1: The name of the target sequence or profile\n3: The name of the query sequence or profile\n8: The start of the alignment of this hit with respect to the\n    sequence, numbered 1..L for a sequence of L residues.\n9: The end of the alignment of this hit with respect to the sequence,\n    numbered 1..L for a sequence of L residues\n\nLikewise the format esl-sfetch wants is: <newname> <from> <to> <source seqname>\n\nPutting it all together we see that the newname (which esl-sfetch with\noutput using) is a concatenation of the original name, the sequence\nnumber, and the coordinates.\n",
            "id": "#extract-coords-from-cmsearch.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "split FASTA by number of records",
            "doc": "based upon code by Maxim Scheremetjew, EMBL-EBI",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69"
                            ],
                            "package": "biopython"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#fasta_chunker.cwl/chunk_size"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#fasta_chunker.cwl/seqs"
                }
            ],
            "baseCommand": "python",
            "arguments": [
                {
                    "prefix": "-c",
                    "valueFrom": "from Bio import SeqIO\ncurrentSequences = []\nfor record in SeqIO.parse(\"$(inputs.seqs.path)\", \"fasta\"):\n    currentSequences.append(record)\n    if len(currentSequences) == $(inputs.chunk_size):\n        fileName = currentSequences[0].id + \"_\" + \\\\\n                       currentSequences[-1].id + \".fasta\"\n        for char in [ \"/\", \" \", \":\" ]:\n            fileName = fileName.replace(char, \"_\")\n        SeqIO.write(currentSequences, \"$(runtime.outdir)/\"+fileName, \"fasta\")\n        currentSequences = []\n\n# write any remaining sequences\nif len(currentSequences) > 0:\n    fileName = currentSequences[0].id + \"_\" + \\\\\n                   currentSequences[-1].id + \".fasta\"\n    for char in [ \"/\", \" \", \":\" ]:\n        fileName = fileName.replace(char, \"_\")\n    SeqIO.write(currentSequences, \"$(runtime.outdir)/\"+fileName, \"fasta\")\n"
                }
            ],
            "outputs": [
                {
                    "format": "http://edamontology.org/format_1929",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#fasta_chunker.cwl/chunks"
                }
            ],
            "id": "#fasta_chunker.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 10240,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005732"
                            ],
                            "version": [
                                "8d53bbce1ffe60d9aa3357c1001599f9a882317a"
                            ],
                            "package": "owltools"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input-file"
                    },
                    "id": "#go_summary.cwl/InterProScan_results"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--config"
                    },
                    "id": "#go_summary.cwl/config"
                }
            ],
            "baseCommand": "go_summary_pipeline-1.0.py",
            "arguments": [
                {
                    "valueFrom": "go-summary",
                    "prefix": "--output-file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/csv",
                    "outputBinding": {
                        "glob": "go-summary"
                    },
                    "id": "#go_summary.cwl/go_summary"
                },
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/csv",
                    "outputBinding": {
                        "glob": "go-summary_slim"
                    },
                    "id": "#go_summary.cwl/go_summary_slim"
                }
            ],
            "id": "#go_summary.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "search sequence(s) against a covariance model database",
            "doc": "http://eddylab.org/infernal/Userguide.pdf",
            "requirements": [
                {
                    "ramMin": 10240,
                    "coresMin": 4,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_011809"
                            ],
                            "version": [
                                "1.1.2"
                            ],
                            "package": "infernal"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#infernal-cmsearch.cwl/covariance_model_database"
                },
                {
                    "label": "use CM's GA gathering cutoffs as reporting thresholds",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "inputBinding": {
                        "prefix": "--cut_ga"
                    },
                    "id": "#infernal-cmsearch.cwl/cut_ga"
                },
                {
                    "label": "Omit the alignment section from the main output.",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--noali"
                    },
                    "doc": "This can greatly reduce the output volume.",
                    "id": "#infernal-cmsearch.cwl/omit_alignment_section"
                },
                {
                    "label": "Only use the filter profile HMM for searches, do not use the CM",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "inputBinding": {
                        "prefix": "--hmmonly"
                    },
                    "doc": "Only filter stages F1 through F3 will be executed, using strict P-value\nthresholds (0.02 for F1, 0.001 for F2 and 0.00001 for F3). Additionally\na bias composition filter is used after the F1 stage (with P=0.02\nsurvival threshold).  Any hit that survives all stages and has an HMM\nE-value or bit score above the reporting threshold will be output. \n",
                    "id": "#infernal-cmsearch.cwl/only_hmm"
                },
                {
                    "type": "File",
                    "streamable": true,
                    "inputBinding": {
                        "position": 1
                    },
                    "format": [
                        "http://edamontology.org/format_1929"
                    ],
                    "id": "#infernal-cmsearch.cwl/query_sequences"
                },
                {
                    "type": "int",
                    "label": "search space size in *Mb* to <x> for E-value calculations",
                    "inputBinding": {
                        "prefix": "-Z"
                    },
                    "id": "#infernal-cmsearch.cwl/search_space_size"
                }
            ],
            "baseCommand": "cmsearch",
            "arguments": [
                {
                    "valueFrom": "matches.tbl",
                    "prefix": "--tblout"
                },
                {
                    "valueFrom": "$(runtime.cores)",
                    "prefix": "--cpu"
                }
            ],
            "outputs": [
                {
                    "label": "target hits table, format 2",
                    "doc": "http://eddylab.org/infernal/Userguide.pdf#page=60",
                    "type": "File",
                    "outputBinding": {
                        "glob": "matches.tbl"
                    },
                    "id": "#infernal-cmsearch.cwl/matches"
                }
            ],
            "id": "#infernal-cmsearch.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "gather stats from InterProScan",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "package": "python"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "id": "#ipr_stats.cwl/iprscan"
                }
            ],
            "baseCommand": "python",
            "arguments": [
                {
                    "prefix": "-c",
                    "valueFrom": "from __future__ import print_function\nimport re\nimport json\nimport yaml\naccessionPattern = re.compile(\"(\\\\S+)_\\\\d+_\\\\d+_[+-]\")\nmatch_count = CDS_with_match_number = reads_with_match_count = 0\ncds = set(); reads = set()\nentry2protein = {}; entry2name = {}\nfor line in open(\"$(inputs.iprscan.path)\", \"r\"):\n    splitLine = line.strip().split(\"\\\\t\")\n    cdsAccessions = splitLine[0].split(\"|\")\n    for cdsAccession in cdsAccessions:\n        if len(splitLine) >= 13 and splitLine[11].startswith(\"IPR\"):\n            entry = splitLine[11]\n            entry2protein.setdefault(entry, set()).add(cdsAccession)\n            entry2name[entry] = splitLine[12]\n        cds.add(cdsAccession)\n        readAccessionMatch = re.match(accessionPattern, cdsAccession)\n        readAccession = readAccessionMatch.group(1)\n        reads.add(readAccession)\n        match_count += 1\nCDS_with_match_count = len(cds)\nwithFunctionFaaList = sorted(list(cds))\nwith open(\"id_list.txt\", \"w\") as idFile:\n    for id in withFunctionFaaList:\n        idFile.write(id + \"\\\\n\")\nreads_with_match_count = len(reads)\nwith open(\"reads.json\", \"w\") as readsFile:\n    json.dump(list(reads), readsFile)\nwith open(\"ipr_entry_maps.yaml\", \"w\") as mapsFile:\n    yaml.dump({\"entry2protein\": entry2protein,\n               \"entry2name\": entry2name}, mapsFile)\nprint(json.dumps({\n    \"match_count\": match_count,\n    \"CDS_with_match_count\": CDS_with_match_count,\n    \"reads_with_match_count\": reads_with_match_count,\n    \"id_list\": {\n        \"class\": \"File\",\n        \"path\": \"$(runtime.outdir)/id_list.txt\" },\n    \"ipr_entry_maps\": {\n        \"class\": \"File\",\n        \"format\": \"https://www.iana.org/assignments/media-types/application/yaml\",\n        \"path\": \"$(runtime.outdir)/ipr_entry_maps.yaml\" },\n    \"reads\": {\n        \"class\": \"File\",\n        \"format\": \"https://www.iana.org/assignments/media-types/application/json\",\n        \"path\": \"$(runtime.outdir)/reads.json\" } }))\n"
                }
            ],
            "stdout": "cwl.output.json",
            "outputs": [
                {
                    "type": "int",
                    "id": "#ipr_stats.cwl/CDS_with_match_count"
                },
                {
                    "type": "File",
                    "streamable": true,
                    "id": "#ipr_stats.cwl/id_list"
                },
                {
                    "type": "File",
                    "streamable": true,
                    "format": "https://www.iana.org/assignments/media-types/application/yaml",
                    "id": "#ipr_stats.cwl/ipr_entry_maps"
                },
                {
                    "type": "int",
                    "id": "#ipr_stats.cwl/match_count"
                },
                {
                    "type": "File",
                    "streamable": true,
                    "format": "https://www.iana.org/assignments/media-types/application/json",
                    "id": "#ipr_stats.cwl/reads"
                },
                {
                    "type": "int",
                    "id": "#ipr_stats.cwl/reads_with_match_count"
                }
            ],
            "id": "#ipr_stats.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "visualize using krona",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_012785"
                            ],
                            "version": [
                                "2.3",
                                "2.7"
                            ],
                            "package": "krona"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "label": "Tab-delimited text file",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#krona.cwl/otu_counts"
                }
            ],
            "baseCommand": "ktImportText",
            "arguments": [
                {
                    "valueFrom": "$(inputs.otu_counts.nameroot).html",
                    "prefix": "-o"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/html",
                    "outputBinding": {
                        "glob": "$(inputs.otu_counts.nameroot).html"
                    },
                    "id": "#krona.cwl/otu_visualization"
                }
            ],
            "id": "#krona.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "MAPseq",
            "doc": "sequence read classification tools designed to assign taxonomy and OTU\nclassifications to ribosomal RNA sequences.\nhttp://meringlab.org/software/mapseq/\n",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 10240,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "version": [
                                "1.0"
                            ],
                            "package": "mapseq"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".mscluster",
                    "inputBinding": {
                        "position": 2
                    },
                    "format": "http://edamontology.org/format_1929",
                    "id": "#mapseq.cwl/database"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "format": "http://edamontology.org/format_1929",
                    "id": "#mapseq.cwl/sequences"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#mapseq.cwl/taxonomy"
                }
            ],
            "baseCommand": "mapseq",
            "arguments": [
                {
                    "valueFrom": "4",
                    "prefix": "-nthreads"
                }
            ],
            "stdout": "classifications",
            "outputs": [
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "id": "#mapseq.cwl/classifications",
                    "outputBinding": {
                        "glob": "classifications"
                    }
                }
            ],
            "id": "#mapseq.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "label": "label to add to the top of the outfile OTU table",
                    "inputBinding": {
                        "prefix": "--label"
                    },
                    "id": "#mapseq2biom.cwl/label"
                },
                {
                    "type": "File",
                    "doc": "the OTU table produced for the taxonomies found in the reference\ndatabases that was used with MAPseq\n",
                    "inputBinding": {
                        "prefix": "--otuTable"
                    },
                    "id": "#mapseq2biom.cwl/otu_table"
                },
                {
                    "type": "File",
                    "label": "the output from the MAPseq that assigns a taxonomy to a sequence",
                    "inputBinding": {
                        "prefix": "--query"
                    },
                    "id": "#mapseq2biom.cwl/query"
                }
            ],
            "baseCommand": "mapseq2biom.pl",
            "arguments": [
                {
                    "valueFrom": "$(inputs.query.basename).tsv",
                    "prefix": "--outfile"
                },
                {
                    "valueFrom": "$(inputs.label).txt",
                    "prefix": "--krona"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.label).txt"
                    },
                    "id": "#mapseq2biom.cwl/krona_otu_counts"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3746",
                    "outputBinding": {
                        "glob": "$(inputs.query.basename).tsv"
                    },
                    "id": "#mapseq2biom.cwl/otu_counts"
                }
            ],
            "id": "#mapseq2biom.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "metaSPAdes: de novo metagenomics assembler",
            "doc": "https://arxiv.org/abs/1604.03071\nhttp://cab.spbu.ru/files/release3.10.1/manual.html#meta\n",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 102400,
                    "coresMin": 16,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_000131"
                            ],
                            "version": [
                                "3.10.1"
                            ],
                            "package": "spades"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-1"
                    },
                    "id": "#metaspades.cwl/forward_reads"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-2"
                    },
                    "id": "#metaspades.cwl/reverse_reads"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#metaspades.cwl/unpaired_reads"
                }
            ],
            "baseCommand": [
                "metaspades.py"
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.outdir)",
                    "prefix": "-o"
                },
                {
                    "valueFrom": "$(runtime.tmpdir)",
                    "prefix": "--tmp-dir"
                },
                {
                    "valueFrom": "$(runtime.ram / 1024)",
                    "prefix": "--memory"
                },
                {
                    "valueFrom": "$(runtime.cores)",
                    "prefix": "--threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "assembly_graph.fastg"
                    },
                    "id": "#metaspades.cwl/assembly_graph"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "contigs.fasta"
                    },
                    "id": "#metaspades.cwl/contigs"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "contigs.paths"
                    },
                    "id": "#metaspades.cwl/contigs_assembly_graph"
                },
                {
                    "label": "contigs before repeat resolution",
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "before_rr.fasta"
                    },
                    "id": "#metaspades.cwl/contigs_before_rr"
                },
                {
                    "label": "internal configuration file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "dataset.info"
                    },
                    "id": "#metaspades.cwl/internal_config"
                },
                {
                    "label": "internal YAML data set file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "input_dataset.yaml"
                    },
                    "id": "#metaspades.cwl/internal_dataset"
                },
                {
                    "label": "SPAdes log",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/plain",
                    "outputBinding": {
                        "glob": "spades.log"
                    },
                    "id": "#metaspades.cwl/log"
                },
                {
                    "label": "information about SPAdes parameters in this run",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/plain",
                    "outputBinding": {
                        "glob": "params.txt"
                    },
                    "id": "#metaspades.cwl/params"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "scaffolds.fasta"
                    },
                    "id": "#metaspades.cwl/scaffolds"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "scaffolds.paths"
                    },
                    "id": "#metaspades.cwl/scaffolds_assembly_graph"
                }
            ],
            "id": "#metaspades.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "gather stats from ORF caller",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69"
                            ],
                            "package": "biopython"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "format": "http://edamontology.org/format_1929",
                    "id": "#orf_stats.cwl/orfs"
                }
            ],
            "baseCommand": "python",
            "arguments": [
                {
                    "prefix": "-c",
                    "valueFrom": "from __future__ import print_function\nimport re\nimport json\nfrom Bio import SeqIO\naccessionPattern = re.compile(\"(\\\\S+)_\\\\d+_\\\\d+_[+-]\")\nnumberOrfs = 0\nreadsWithOrf = set()\nfor record in SeqIO.parse(\"$(inputs.orfs.path)\", \"fasta\"):\n    readAccessionMatch = re.match(accessionPattern, record.id)\n    readAccession = readAccessionMatch.group(1)\n    readsWithOrf.add(readAccession)\n    numberOrfs += 1\nnumberReadsWithOrf = len(readsWithOrf)\nwith open(\"reads.json\", \"w\") as readsFile:\n    json.dump(list(readsWithOrf), readsFile)\nprint(json.dumps({\n  \"numberReadsWithOrf\": numberReadsWithOrf,\n  \"numberOrfs\": numberOrfs,\n  \"readsWithOrf\":{\n      \"class\": \"File\",\n      \"format\": \"https://www.iana.org/assignments/media-types/application/json\",\n      \"path\": \"$(runtime.outdir)/reads.json\" } }))\n"
                }
            ],
            "stdout": "cwl.output.json",
            "outputs": [
                {
                    "type": "int",
                    "id": "#orf_stats.cwl/numberOrfs"
                },
                {
                    "type": "int",
                    "id": "#orf_stats.cwl/numberReadsWithOrf"
                },
                {
                    "type": "File",
                    "streamable": true,
                    "format": "https://www.iana.org/assignments/media-types/application/json",
                    "id": "#orf_stats.cwl/readsWithOrf"
                }
            ],
            "id": "#orf_stats.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "id": "#pull-5Ss.cwl/hits"
                }
            ],
            "stdin": "${inputs.hits.path}",
            "baseCommand": [
                "grep",
                "RF00002"
            ],
            "stdout": "5Ss",
            "outputs": [
                {
                    "type": "File",
                    "id": "#pull-5Ss.cwl/5Ss",
                    "outputBinding": {
                        "glob": "5Ss"
                    }
                }
            ],
            "id": "#pull-5Ss.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "id": "#pull-LSUs.cwl/hits"
                }
            ],
            "stdin": "$(inputs.hits.path)",
            "baseCommand": [
                "grep",
                "-e RF02543 -e RF02541 -e RF02541 -e RF00002"
            ],
            "stdout": "LSUs",
            "outputs": [
                {
                    "type": "File",
                    "id": "#pull-LSUs.cwl/LSUs",
                    "outputBinding": {
                        "glob": "LSUs"
                    }
                }
            ],
            "id": "#pull-LSUs.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "id": "#pull-SSUs.cwl/hits"
                }
            ],
            "stdin": "$(inputs.hits.path)",
            "baseCommand": [
                "grep",
                "SSU"
            ],
            "stdout": "SSUs",
            "outputs": [
                {
                    "type": "File",
                    "id": "#pull-SSUs.cwl/SSUs",
                    "outputBinding": {
                        "glob": "SSUs"
                    }
                }
            ],
            "id": "#pull-SSUs.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "Post QC-ed input analysis of sequence file",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#qc-stats.cwl/QCed_reads"
                },
                {
                    "label": "Prefix for the files associated with GC distribution",
                    "type": "string",
                    "default": "GC-distribution.out",
                    "inputBinding": {
                        "prefix": "-g"
                    },
                    "id": "#qc-stats.cwl/gc_sum"
                },
                {
                    "label": "Prefix for the files assocaited with sequence length distribution",
                    "type": "string",
                    "default": "seq-length.out",
                    "inputBinding": {
                        "prefix": "-l"
                    },
                    "id": "#qc-stats.cwl/length_sum"
                },
                {
                    "label": "Maximum number of sequences to sub-sample",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2000000,
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "id": "#qc-stats.cwl/max_seq"
                },
                {
                    "label": "Prefix for the files associated with nucleotide distribution",
                    "type": "string",
                    "default": "nucleotide-distribution.out",
                    "inputBinding": {
                        "prefix": "-d"
                    },
                    "id": "#qc-stats.cwl/nucleotide_distribution"
                },
                {
                    "label": "File names for summary of sequences, e.g. number, min/max length etc.",
                    "type": "string",
                    "default": "summary.out",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#qc-stats.cwl/summary"
                }
            ],
            "baseCommand": [
                "MGRAST_base.py"
            ],
            "outputs": [
                {
                    "label": "Contains the binned GC distribution, real numbers",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.gc_sum)_bin"
                    },
                    "id": "#qc-stats.cwl/gc_sum_bin"
                },
                {
                    "label": "Contains all GC fractsions observed and sequence counts",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.gc_sum)"
                    },
                    "id": "#qc-stats.cwl/gc_sum_out"
                },
                {
                    "label": "Contains the binned GC distribution, percentage",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.gc_sum)_pcbin"
                    },
                    "id": "#qc-stats.cwl/gc_sum_pcbin"
                },
                {
                    "label": "Contains the normalised fraction of nucleotides on the sequences",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.nucleotide_distribution)"
                    },
                    "id": "#qc-stats.cwl/nucleotide_distribution_out"
                },
                {
                    "label": "Contains the binned length distribution, real numbers",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.length_sum)_bin"
                    },
                    "id": "#qc-stats.cwl/seq_length_bin"
                },
                {
                    "label": "Contains all the lengths observed and frequencies",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.length_sum)"
                    },
                    "id": "#qc-stats.cwl/seq_length_out"
                },
                {
                    "label": "Contains the binned length distribution expressed as percentage",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.length_sum)_pcbin"
                    },
                    "id": "#qc-stats.cwl/seq_length_pcbin"
                },
                {
                    "label": "Contains the summary statistics for the input sequence file",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/plain",
                    "outputBinding": {
                        "glob": "$(inputs.summary)"
                    },
                    "id": "#qc-stats.cwl/summary_out"
                }
            ],
            "id": "#qc-stats.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#cmsearch-multimodel.cwl/clan_info"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#cmsearch-multimodel.cwl/covariance_models"
                },
                {
                    "type": "File",
                    "id": "#cmsearch-multimodel.cwl/query_sequences"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#cmsearch-multimodel.cwl/remove_overlaps/deoverlapped_matches",
                    "id": "#cmsearch-multimodel.cwl/matches"
                }
            ],
            "steps": [
                {
                    "run": "#infernal-cmsearch.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-multimodel.cwl/covariance_models",
                            "id": "#cmsearch-multimodel.cwl/cmsearch/covariance_model_database"
                        },
                        {
                            "default": true,
                            "id": "#cmsearch-multimodel.cwl/cmsearch/omit_alignment_section"
                        },
                        {
                            "default": true,
                            "id": "#cmsearch-multimodel.cwl/cmsearch/only_hmm"
                        },
                        {
                            "source": "#cmsearch-multimodel.cwl/query_sequences",
                            "id": "#cmsearch-multimodel.cwl/cmsearch/query_sequences"
                        },
                        {
                            "default": 1000,
                            "id": "#cmsearch-multimodel.cwl/cmsearch/search_space_size"
                        }
                    ],
                    "out": [
                        "#cmsearch-multimodel.cwl/cmsearch/matches"
                    ],
                    "scatter": "#cmsearch-multimodel.cwl/cmsearch/covariance_model_database",
                    "id": "#cmsearch-multimodel.cwl/cmsearch"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-multimodel.cwl/cmsearch/matches",
                            "id": "#cmsearch-multimodel.cwl/concatenate_matches/files"
                        }
                    ],
                    "out": [
                        "#cmsearch-multimodel.cwl/concatenate_matches/result"
                    ],
                    "id": "#cmsearch-multimodel.cwl/concatenate_matches"
                },
                {
                    "run": "#cmsearch-deoverlap.cwl",
                    "in": [
                        {
                            "source": "#cmsearch-multimodel.cwl/clan_info",
                            "id": "#cmsearch-multimodel.cwl/remove_overlaps/clan_information"
                        },
                        {
                            "source": "#cmsearch-multimodel.cwl/concatenate_matches/result",
                            "id": "#cmsearch-multimodel.cwl/remove_overlaps/cmsearch_matches"
                        }
                    ],
                    "out": [
                        "#cmsearch-multimodel.cwl/remove_overlaps/deoverlapped_matches"
                    ],
                    "id": "#cmsearch-multimodel.cwl/remove_overlaps"
                }
            ],
            "id": "#cmsearch-multimodel.cwl"
        },
        {
            "class": "Workflow",
            "label": "EMG core analysis",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#FragGeneScan-model.yaml/model"
                        },
                        {
                            "$import": "#InterProScan-apps.yaml/apps"
                        },
                        {
                            "$import": "#InterProScan-protein_formats.yaml/protein_formats"
                        },
                        {
                            "$import": "#esl-reformat-replace.yaml/replace"
                        },
                        {
                            "$import": "#biom-convert-table.yaml/table_type"
                        },
                        {
                            "type": "record",
                            "name": "#trimmomatic-sliding_window.yaml/slidingWindow",
                            "fields": [
                                {
                                    "name": "#trimmomatic-sliding_window.yaml/slidingWindow/windowSize",
                                    "type": "int"
                                },
                                {
                                    "name": "#trimmomatic-sliding_window.yaml/slidingWindow/requiredQuality",
                                    "type": "int"
                                }
                            ]
                        },
                        {
                            "type": "enum",
                            "name": "#trimmomatic-end_mode.yaml/end_mode",
                            "symbols": [
                                "#trimmomatic-end_mode.yaml/end_mode/SE",
                                "#trimmomatic-end_mode.yaml/end_mode/PE"
                            ]
                        },
                        {
                            "type": "enum",
                            "name": "#trimmomatic-phred.yaml/phred",
                            "symbols": [
                                "#trimmomatic-phred.yaml/phred/64",
                                "#trimmomatic-phred.yaml/phred/33"
                            ]
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "#FragGeneScan-model.yaml/model",
                    "id": "#emg-core-analysis-v4.cwl/fraggenescan_model"
                },
                {
                    "type": "File",
                    "id": "#emg-core-analysis-v4.cwl/go_summary_config"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#emg-core-analysis-v4.cwl/input_sequences"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "secondaryFiles": ".mscluster",
                    "id": "#emg-core-analysis-v4.cwl/mapseq_ref"
                },
                {
                    "type": "File",
                    "id": "#emg-core-analysis-v4.cwl/mapseq_taxonomy"
                },
                {
                    "type": "File",
                    "id": "#emg-core-analysis-v4.cwl/ncRNA_other_model_clans"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#emg-core-analysis-v4.cwl/ncRNA_other_models"
                },
                {
                    "type": "File",
                    "id": "#emg-core-analysis-v4.cwl/ncRNA_ribosomal_model_clans"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#emg-core-analysis-v4.cwl/ncRNA_ribosomal_models"
                },
                {
                    "type": "string",
                    "id": "#emg-core-analysis-v4.cwl/sequencing_run_id"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/extract_5Ss/sequences",
                    "id": "#emg-core-analysis-v4.cwl/5S_sequences"
                },
                {
                    "type": "int",
                    "outputSource": "#emg-core-analysis-v4.cwl/ipr_stats/CDS_with_match_count",
                    "id": "#emg-core-analysis-v4.cwl/CDS_with_match_count"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/extract_LSUs/sequences",
                    "id": "#emg-core-analysis-v4.cwl/LSU_sequences"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/extract_SSUs/sequences",
                    "id": "#emg-core-analysis-v4.cwl/SSU_sequences"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/functional_analysis/functional_annotations",
                    "id": "#emg-core-analysis-v4.cwl/functional_annotations"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/functional_analysis/go_summary",
                    "id": "#emg-core-analysis-v4.cwl/go_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/functional_analysis/go_summary_slim",
                    "id": "#emg-core-analysis-v4.cwl/go_summary_slim"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/categorisation/interproscan",
                    "id": "#emg-core-analysis-v4.cwl/interproscan"
                },
                {
                    "type": "int",
                    "outputSource": "#emg-core-analysis-v4.cwl/ipr_stats/match_count",
                    "id": "#emg-core-analysis-v4.cwl/match_count"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/categorisation/no_functions_seqs",
                    "id": "#emg-core-analysis-v4.cwl/no_functions_seqs"
                },
                {
                    "type": "int",
                    "outputSource": "#emg-core-analysis-v4.cwl/orf_stats/numberOrfs",
                    "id": "#emg-core-analysis-v4.cwl/numberOrfs"
                },
                {
                    "type": "int",
                    "outputSource": "#emg-core-analysis-v4.cwl/orf_stats/numberReadsWithOrf",
                    "id": "#emg-core-analysis-v4.cwl/numberReadsWithOrf"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/find_other_ncRNAs/matches",
                    "id": "#emg-core-analysis-v4.cwl/other_ncRNAs"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/categorisation/pCDS_seqs",
                    "id": "#emg-core-analysis-v4.cwl/pCDS_seqs"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/ORF_prediction/predicted_CDS_aa",
                    "id": "#emg-core-analysis-v4.cwl/predicted_CDS"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/sequence_stats/gc_sum_out",
                    "id": "#emg-core-analysis-v4.cwl/qc_stats_gc"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/sequence_stats/gc_sum_bin",
                    "id": "#emg-core-analysis-v4.cwl/qc_stats_gc_bin"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/sequence_stats/gc_sum_pcbin",
                    "id": "#emg-core-analysis-v4.cwl/qc_stats_gc_pcbin"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/sequence_stats/nucleotide_distribution_out",
                    "id": "#emg-core-analysis-v4.cwl/qc_stats_nuc_dist"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/sequence_stats/seq_length_out",
                    "id": "#emg-core-analysis-v4.cwl/qc_stats_seq_len"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/sequence_stats/seq_length_bin",
                    "id": "#emg-core-analysis-v4.cwl/qc_stats_seq_len_bin"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/sequence_stats/seq_length_pcbin",
                    "id": "#emg-core-analysis-v4.cwl/qc_stats_seq_len_pcbin"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/sequence_stats/summary_out",
                    "id": "#emg-core-analysis-v4.cwl/qc_stats_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/orf_stats/readsWithOrf",
                    "id": "#emg-core-analysis-v4.cwl/readsWithOrf"
                },
                {
                    "type": "int",
                    "outputSource": "#emg-core-analysis-v4.cwl/ipr_stats/reads_with_match_count",
                    "id": "#emg-core-analysis-v4.cwl/reads_with_match_count"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/classify_SSUs/classifications",
                    "id": "#emg-core-analysis-v4.cwl/ssu_classifications"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/convert_otu_counts_to_hdf5/result",
                    "id": "#emg-core-analysis-v4.cwl/ssu_otu_counts_hdf5"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/convert_otu_counts_to_json/result",
                    "id": "#emg-core-analysis-v4.cwl/ssu_otu_counts_json"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/visualize_otu_counts/otu_visualization",
                    "id": "#emg-core-analysis-v4.cwl/ssu_otu_visualization"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-core-analysis-v4.cwl/ipr_stats/reads",
                    "id": "#emg-core-analysis-v4.cwl/stats_reads"
                }
            ],
            "steps": [
                {
                    "run": "#orf_prediction.cwl",
                    "in": [
                        {
                            "default": false,
                            "id": "#emg-core-analysis-v4.cwl/ORF_prediction/completeSeq"
                        },
                        {
                            "source": "#emg-core-analysis-v4.cwl/fraggenescan_model",
                            "id": "#emg-core-analysis-v4.cwl/ORF_prediction/model"
                        },
                        {
                            "source": "#emg-core-analysis-v4.cwl/input_sequences",
                            "id": "#emg-core-analysis-v4.cwl/ORF_prediction/sequence"
                        }
                    ],
                    "out": [
                        "#emg-core-analysis-v4.cwl/ORF_prediction/predicted_CDS_aa"
                    ],
                    "id": "#emg-core-analysis-v4.cwl/ORF_prediction"
                },
                {
                    "run": "#create_categorisations.cwl",
                    "in": [
                        {
                            "source": "#emg-core-analysis-v4.cwl/orf_stats/readsWithOrf",
                            "id": "#emg-core-analysis-v4.cwl/categorisation/cds_idset"
                        },
                        {
                            "source": "#emg-core-analysis-v4.cwl/ipr_stats/reads",
                            "id": "#emg-core-analysis-v4.cwl/categorisation/ipr_idset"
                        },
                        {
                            "source": "#emg-core-analysis-v4.cwl/extract_SSUs/sequences",
                            "id": "#emg-core-analysis-v4.cwl/categorisation/seqs"
                        }
                    ],
                    "out": [
                        "#emg-core-analysis-v4.cwl/categorisation/interproscan",
                        "#emg-core-analysis-v4.cwl/categorisation/pCDS_seqs",
                        "#emg-core-analysis-v4.cwl/categorisation/no_functions_seqs"
                    ],
                    "id": "#emg-core-analysis-v4.cwl/categorisation"
                },
                {
                    "run": "#mapseq.cwl",
                    "in": [
                        {
                            "source": "#emg-core-analysis-v4.cwl/mapseq_ref",
                            "id": "#emg-core-analysis-v4.cwl/classify_SSUs/database"
                        },
                        {
                            "source": "#emg-core-analysis-v4.cwl/extract_SSUs/sequences",
                            "id": "#emg-core-analysis-v4.cwl/classify_SSUs/sequences"
                        },
                        {
                            "source": "#emg-core-analysis-v4.cwl/mapseq_taxonomy",
                            "id": "#emg-core-analysis-v4.cwl/classify_SSUs/taxonomy"
                        }
                    ],
                    "out": [
                        "#emg-core-analysis-v4.cwl/classify_SSUs/classifications"
                    ],
                    "id": "#emg-core-analysis-v4.cwl/classify_SSUs"
                },
                {
                    "run": "#mapseq2biom.cwl",
                    "in": [
                        {
                            "source": "#emg-core-analysis-v4.cwl/sequencing_run_id",
                            "id": "#emg-core-analysis-v4.cwl/convert_classifications_to_otu_counts/label"
                        },
                        {
                            "source": "#emg-core-analysis-v4.cwl/mapseq_taxonomy",
                            "id": "#emg-core-analysis-v4.cwl/convert_classifications_to_otu_counts/otu_table"
                        },
                        {
                            "source": "#emg-core-analysis-v4.cwl/classify_SSUs/classifications",
                            "id": "#emg-core-analysis-v4.cwl/convert_classifications_to_otu_counts/query"
                        }
                    ],
                    "out": [
                        "#emg-core-analysis-v4.cwl/convert_classifications_to_otu_counts/otu_counts",
                        "#emg-core-analysis-v4.cwl/convert_classifications_to_otu_counts/krona_otu_counts"
                    ],
                    "id": "#emg-core-analysis-v4.cwl/convert_classifications_to_otu_counts"
                },
                {
                    "run": "#biom-convert.cwl",
                    "in": [
                        {
                            "source": "#emg-core-analysis-v4.cwl/convert_classifications_to_otu_counts/otu_counts",
                            "id": "#emg-core-analysis-v4.cwl/convert_otu_counts_to_hdf5/biom"
                        },
                        {
                            "default": true,
                            "id": "#emg-core-analysis-v4.cwl/convert_otu_counts_to_hdf5/hdf5"
                        },
                        {
                            "default": "OTU table",
                            "id": "#emg-core-analysis-v4.cwl/convert_otu_counts_to_hdf5/table_type"
                        }
                    ],
                    "out": [
                        "#emg-core-analysis-v4.cwl/convert_otu_counts_to_hdf5/result"
                    ],
                    "id": "#emg-core-analysis-v4.cwl/convert_otu_counts_to_hdf5"
                },
                {
                    "run": "#biom-convert.cwl",
                    "in": [
                        {
                            "source": "#emg-core-analysis-v4.cwl/convert_classifications_to_otu_counts/otu_counts",
                            "id": "#emg-core-analysis-v4.cwl/convert_otu_counts_to_json/biom"
                        },
                        {
                            "default": true,
                            "id": "#emg-core-analysis-v4.cwl/convert_otu_counts_to_json/json"
                        },
                        {
                            "default": "OTU table",
                            "id": "#emg-core-analysis-v4.cwl/convert_otu_counts_to_json/table_type"
                        }
                    ],
                    "out": [
                        "#emg-core-analysis-v4.cwl/convert_otu_counts_to_json/result"
                    ],
                    "id": "#emg-core-analysis-v4.cwl/convert_otu_counts_to_json"
                },
                {
                    "run": "#esl-sfetch-manyseqs.cwl",
                    "in": [
                        {
                            "source": "#emg-core-analysis-v4.cwl/index_reads/sequences_with_index",
                            "id": "#emg-core-analysis-v4.cwl/extract_5Ss/indexed_sequences"
                        },
                        {
                            "source": "#emg-core-analysis-v4.cwl/get_5S_coords/5S_coordinates",
                            "id": "#emg-core-analysis-v4.cwl/extract_5Ss/names"
                        },
                        {
                            "default": true,
                            "id": "#emg-core-analysis-v4.cwl/extract_5Ss/names_contain_subseq_coords"
                        }
                    ],
                    "out": [
                        "#emg-core-analysis-v4.cwl/extract_5Ss/sequences"
                    ],
                    "id": "#emg-core-analysis-v4.cwl/extract_5Ss"
                },
                {
                    "run": "#esl-sfetch-manyseqs.cwl",
                    "in": [
                        {
                            "source": "#emg-core-analysis-v4.cwl/index_reads/sequences_with_index",
                            "id": "#emg-core-analysis-v4.cwl/extract_LSUs/indexed_sequences"
                        },
                        {
                            "source": "#emg-core-analysis-v4.cwl/get_LSU_coords/LSU_coordinates",
                            "id": "#emg-core-analysis-v4.cwl/extract_LSUs/names"
                        },
                        {
                            "default": true,
                            "id": "#emg-core-analysis-v4.cwl/extract_LSUs/names_contain_subseq_coords"
                        }
                    ],
                    "out": [
                        "#emg-core-analysis-v4.cwl/extract_LSUs/sequences"
                    ],
                    "id": "#emg-core-analysis-v4.cwl/extract_LSUs"
                },
                {
                    "run": "#esl-sfetch-manyseqs.cwl",
                    "in": [
                        {
                            "source": "#emg-core-analysis-v4.cwl/index_reads/sequences_with_index",
                            "id": "#emg-core-analysis-v4.cwl/extract_SSUs/indexed_sequences"
                        },
                        {
                            "source": "#emg-core-analysis-v4.cwl/get_SSU_coords/SSU_coordinates",
                            "id": "#emg-core-analysis-v4.cwl/extract_SSUs/names"
                        },
                        {
                            "default": true,
                            "id": "#emg-core-analysis-v4.cwl/extract_SSUs/names_contain_subseq_coords"
                        }
                    ],
                    "out": [
                        "#emg-core-analysis-v4.cwl/extract_SSUs/sequences"
                    ],
                    "id": "#emg-core-analysis-v4.cwl/extract_SSUs"
                },
                {
                    "run": "#cmsearch-multimodel.cwl",
                    "in": [
                        {
                            "source": "#emg-core-analysis-v4.cwl/ncRNA_other_model_clans",
                            "id": "#emg-core-analysis-v4.cwl/find_other_ncRNAs/clan_info"
                        },
                        {
                            "source": "#emg-core-analysis-v4.cwl/ncRNA_other_models",
                            "id": "#emg-core-analysis-v4.cwl/find_other_ncRNAs/covariance_models"
                        },
                        {
                            "source": "#emg-core-analysis-v4.cwl/input_sequences",
                            "id": "#emg-core-analysis-v4.cwl/find_other_ncRNAs/query_sequences"
                        }
                    ],
                    "out": [
                        "#emg-core-analysis-v4.cwl/find_other_ncRNAs/matches"
                    ],
                    "id": "#emg-core-analysis-v4.cwl/find_other_ncRNAs"
                },
                {
                    "run": "#cmsearch-multimodel.cwl",
                    "in": [
                        {
                            "source": "#emg-core-analysis-v4.cwl/ncRNA_ribosomal_model_clans",
                            "id": "#emg-core-analysis-v4.cwl/find_ribosomal_ncRNAs/clan_info"
                        },
                        {
                            "source": "#emg-core-analysis-v4.cwl/ncRNA_ribosomal_models",
                            "id": "#emg-core-analysis-v4.cwl/find_ribosomal_ncRNAs/covariance_models"
                        },
                        {
                            "source": "#emg-core-analysis-v4.cwl/input_sequences",
                            "id": "#emg-core-analysis-v4.cwl/find_ribosomal_ncRNAs/query_sequences"
                        }
                    ],
                    "out": [
                        "#emg-core-analysis-v4.cwl/find_ribosomal_ncRNAs/matches"
                    ],
                    "id": "#emg-core-analysis-v4.cwl/find_ribosomal_ncRNAs"
                },
                {
                    "doc": "Matches are generated against predicted CDS, using a sub set of databases\n(Pfam, TIGRFAM, PRINTS, PROSITE patterns, Gene3d) from InterPro. \n",
                    "run": "#functional_analysis.cwl",
                    "in": [
                        {
                            "source": "#emg-core-analysis-v4.cwl/go_summary_config",
                            "id": "#emg-core-analysis-v4.cwl/functional_analysis/go_summary_config"
                        },
                        {
                            "source": "#emg-core-analysis-v4.cwl/remove_asterisks_and_reformat/reformatted_sequences",
                            "id": "#emg-core-analysis-v4.cwl/functional_analysis/predicted_CDS"
                        }
                    ],
                    "out": [
                        "#emg-core-analysis-v4.cwl/functional_analysis/functional_annotations",
                        "#emg-core-analysis-v4.cwl/functional_analysis/go_summary",
                        "#emg-core-analysis-v4.cwl/functional_analysis/go_summary_slim"
                    ],
                    "id": "#emg-core-analysis-v4.cwl/functional_analysis"
                },
                {
                    "run": "#5S-from-tablehits.cwl",
                    "in": [
                        {
                            "source": "#emg-core-analysis-v4.cwl/find_ribosomal_ncRNAs/matches",
                            "id": "#emg-core-analysis-v4.cwl/get_5S_coords/table_hits"
                        }
                    ],
                    "out": [
                        "#emg-core-analysis-v4.cwl/get_5S_coords/5S_coordinates"
                    ],
                    "id": "#emg-core-analysis-v4.cwl/get_5S_coords"
                },
                {
                    "run": "#LSU-from-tablehits.cwl",
                    "in": [
                        {
                            "source": "#emg-core-analysis-v4.cwl/find_ribosomal_ncRNAs/matches",
                            "id": "#emg-core-analysis-v4.cwl/get_LSU_coords/table_hits"
                        }
                    ],
                    "out": [
                        "#emg-core-analysis-v4.cwl/get_LSU_coords/LSU_coordinates"
                    ],
                    "id": "#emg-core-analysis-v4.cwl/get_LSU_coords"
                },
                {
                    "run": "#SSU-from-tablehits.cwl",
                    "in": [
                        {
                            "source": "#emg-core-analysis-v4.cwl/find_ribosomal_ncRNAs/matches",
                            "id": "#emg-core-analysis-v4.cwl/get_SSU_coords/table_hits"
                        }
                    ],
                    "out": [
                        "#emg-core-analysis-v4.cwl/get_SSU_coords/SSU_coordinates"
                    ],
                    "id": "#emg-core-analysis-v4.cwl/get_SSU_coords"
                },
                {
                    "run": "#esl-sfetch-index.cwl",
                    "in": [
                        {
                            "source": "#emg-core-analysis-v4.cwl/input_sequences",
                            "id": "#emg-core-analysis-v4.cwl/index_reads/sequences"
                        }
                    ],
                    "out": [
                        "#emg-core-analysis-v4.cwl/index_reads/sequences_with_index"
                    ],
                    "id": "#emg-core-analysis-v4.cwl/index_reads"
                },
                {
                    "run": "#ipr_stats.cwl",
                    "in": [
                        {
                            "source": "#emg-core-analysis-v4.cwl/functional_analysis/functional_annotations",
                            "id": "#emg-core-analysis-v4.cwl/ipr_stats/iprscan"
                        }
                    ],
                    "out": [
                        "#emg-core-analysis-v4.cwl/ipr_stats/match_count",
                        "#emg-core-analysis-v4.cwl/ipr_stats/CDS_with_match_count",
                        "#emg-core-analysis-v4.cwl/ipr_stats/reads_with_match_count",
                        "#emg-core-analysis-v4.cwl/ipr_stats/reads",
                        "#emg-core-analysis-v4.cwl/ipr_stats/id_list"
                    ],
                    "id": "#emg-core-analysis-v4.cwl/ipr_stats"
                },
                {
                    "run": "#orf_stats.cwl",
                    "in": [
                        {
                            "source": "#emg-core-analysis-v4.cwl/ORF_prediction/predicted_CDS_aa",
                            "id": "#emg-core-analysis-v4.cwl/orf_stats/orfs"
                        }
                    ],
                    "out": [
                        "#emg-core-analysis-v4.cwl/orf_stats/numberReadsWithOrf",
                        "#emg-core-analysis-v4.cwl/orf_stats/numberOrfs",
                        "#emg-core-analysis-v4.cwl/orf_stats/readsWithOrf"
                    ],
                    "id": "#emg-core-analysis-v4.cwl/orf_stats"
                },
                {
                    "run": "#esl-reformat.cwl",
                    "in": [
                        {
                            "default": {
                                "find": "*",
                                "replace": "X"
                            },
                            "id": "#emg-core-analysis-v4.cwl/remove_asterisks_and_reformat/replace"
                        },
                        {
                            "source": "#emg-core-analysis-v4.cwl/ORF_prediction/predicted_CDS_aa",
                            "id": "#emg-core-analysis-v4.cwl/remove_asterisks_and_reformat/sequences"
                        }
                    ],
                    "out": [
                        "#emg-core-analysis-v4.cwl/remove_asterisks_and_reformat/reformatted_sequences"
                    ],
                    "id": "#emg-core-analysis-v4.cwl/remove_asterisks_and_reformat"
                },
                {
                    "run": "#qc-stats.cwl",
                    "in": [
                        {
                            "source": "#emg-core-analysis-v4.cwl/input_sequences",
                            "id": "#emg-core-analysis-v4.cwl/sequence_stats/QCed_reads"
                        }
                    ],
                    "out": [
                        "#emg-core-analysis-v4.cwl/sequence_stats/summary_out",
                        "#emg-core-analysis-v4.cwl/sequence_stats/seq_length_pcbin",
                        "#emg-core-analysis-v4.cwl/sequence_stats/seq_length_bin",
                        "#emg-core-analysis-v4.cwl/sequence_stats/seq_length_out",
                        "#emg-core-analysis-v4.cwl/sequence_stats/nucleotide_distribution_out",
                        "#emg-core-analysis-v4.cwl/sequence_stats/gc_sum_pcbin",
                        "#emg-core-analysis-v4.cwl/sequence_stats/gc_sum_bin",
                        "#emg-core-analysis-v4.cwl/sequence_stats/gc_sum_out"
                    ],
                    "id": "#emg-core-analysis-v4.cwl/sequence_stats"
                },
                {
                    "run": "#krona.cwl",
                    "in": [
                        {
                            "source": "#emg-core-analysis-v4.cwl/convert_classifications_to_otu_counts/krona_otu_counts",
                            "id": "#emg-core-analysis-v4.cwl/visualize_otu_counts/otu_counts"
                        }
                    ],
                    "out": [
                        "#emg-core-analysis-v4.cwl/visualize_otu_counts/otu_visualization"
                    ],
                    "id": "#emg-core-analysis-v4.cwl/visualize_otu_counts"
                }
            ],
            "id": "#emg-core-analysis-v4.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "EMG assembly for paired end Illumina",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#FragGeneScan-model.yaml/model"
                        },
                        {
                            "$import": "#InterProScan-apps.yaml/apps"
                        },
                        {
                            "$import": "#InterProScan-protein_formats.yaml/protein_formats"
                        },
                        {
                            "$import": "#esl-reformat-replace.yaml/replace"
                        },
                        {
                            "$import": "#biom-convert-table.yaml/table_type"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "id": "#main/forward_reads"
                },
                {
                    "type": "#FragGeneScan-model.yaml/model",
                    "id": "#main/fraggenescan_model"
                },
                {
                    "type": "File",
                    "id": "#main/go_summary_config"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "secondaryFiles": ".mscluster",
                    "id": "#main/mapseq_ref"
                },
                {
                    "type": "File",
                    "id": "#main/mapseq_taxonomy"
                },
                {
                    "type": "File",
                    "id": "#main/mapseq_taxonomy_otu_table"
                },
                {
                    "type": "File",
                    "id": "#main/ncRNA_other_model_clans"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/ncRNA_other_models"
                },
                {
                    "type": "File",
                    "id": "#main/ncRNA_ribosomal_model_clans"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/ncRNA_ribosomal_models"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "id": "#main/reverse_reads"
                },
                {
                    "type": "string",
                    "id": "#main/sequencing_run_id"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "id": "#main/unpaired_reads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/5S_sequences",
                    "id": "#main/5S_sequences"
                },
                {
                    "type": "int",
                    "outputSource": "#main/unified_processing/CDS_with_match_count",
                    "id": "#main/CDS_with_match_count"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/LSU_sequences",
                    "id": "#main/LSU_sequences"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/SSU_sequences",
                    "id": "#main/SSU_sequences"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/functional_annotations",
                    "id": "#main/functional_annotations"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/go_summary",
                    "id": "#main/go_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/go_summary_slim",
                    "id": "#main/go_summary_slim"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/interproscan",
                    "id": "#main/interproscan"
                },
                {
                    "type": "int",
                    "outputSource": "#main/unified_processing/match_count",
                    "id": "#main/match_count"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/no_functions_seqs",
                    "id": "#main/no_functions_seqs"
                },
                {
                    "type": "int",
                    "outputSource": "#main/unified_processing/numberOrfs",
                    "id": "#main/numberOrfs"
                },
                {
                    "type": "int",
                    "outputSource": "#main/unified_processing/numberReadsWithOrf",
                    "id": "#main/numberReadsWithOrf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/other_ncRNAs",
                    "id": "#main/other_ncRNAs"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/pCDS_seqs",
                    "id": "#main/pCDS_seqs"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/predicted_CDS",
                    "id": "#main/predicted_CDS"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/qc_stats_gc",
                    "id": "#main/qc_stats_gc"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/qc_stats_gc_bin",
                    "id": "#main/qc_stats_gc_bin"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/qc_stats_gc_pcbin",
                    "id": "#main/qc_stats_gc_pcbin"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/qc_stats_nuc_dist",
                    "id": "#main/qc_stats_nuc_dist"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/qc_stats_seq_len",
                    "id": "#main/qc_stats_seq_len"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/qc_stats_seq_len_bin",
                    "id": "#main/qc_stats_seq_len_bin"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/qc_stats_seq_len_pcbin",
                    "id": "#main/qc_stats_seq_len_pbcbin"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/qc_stats_summary",
                    "id": "#main/qc_stats_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/readsWithOrf",
                    "id": "#main/readsWithOrf"
                },
                {
                    "type": "int",
                    "outputSource": "#main/unified_processing/reads_with_match_count",
                    "id": "#main/reads_with_match_count"
                },
                {
                    "type": "File",
                    "outputSource": "#main/discard_short_scaffolds/filtered_sequences",
                    "id": "#main/scaffolds"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/ssu_classifications",
                    "id": "#main/ssu_classifications"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/stats_reads",
                    "id": "#main/stats_reads"
                }
            ],
            "steps": [
                {
                    "run": "#metaspades.cwl",
                    "in": [
                        {
                            "source": "#main/forward_reads",
                            "id": "#main/assembly/forward_reads"
                        },
                        {
                            "source": "#main/reverse_reads",
                            "id": "#main/assembly/reverse_reads"
                        },
                        {
                            "source": "#main/unpaired_reads",
                            "id": "#main/assembly/unpaired_reads"
                        }
                    ],
                    "out": [
                        "#main/assembly/scaffolds"
                    ],
                    "id": "#main/assembly"
                },
                {
                    "run": "#discard_short_seqs.cwl",
                    "in": [
                        {
                            "default": 100,
                            "id": "#main/discard_short_scaffolds/minimum_length"
                        },
                        {
                            "source": "#main/assembly/scaffolds",
                            "id": "#main/discard_short_scaffolds/sequences"
                        }
                    ],
                    "out": [
                        "#main/discard_short_scaffolds/filtered_sequences"
                    ],
                    "id": "#main/discard_short_scaffolds"
                },
                {
                    "label": "continue with the main workflow",
                    "run": "#emg-core-analysis-v4.cwl",
                    "in": [
                        {
                            "source": "#main/fraggenescan_model",
                            "id": "#main/unified_processing/fraggenescan_model"
                        },
                        {
                            "source": "#main/go_summary_config",
                            "id": "#main/unified_processing/go_summary_config"
                        },
                        {
                            "source": "#main/discard_short_scaffolds/filtered_sequences",
                            "id": "#main/unified_processing/input_sequences"
                        },
                        {
                            "source": "#main/mapseq_ref",
                            "id": "#main/unified_processing/mapseq_ref"
                        },
                        {
                            "source": "#main/mapseq_taxonomy",
                            "id": "#main/unified_processing/mapseq_taxonomy"
                        },
                        {
                            "source": "#main/ncRNA_other_model_clans",
                            "id": "#main/unified_processing/ncRNA_other_model_clans"
                        },
                        {
                            "source": "#main/ncRNA_other_models",
                            "id": "#main/unified_processing/ncRNA_other_models"
                        },
                        {
                            "source": "#main/ncRNA_ribosomal_model_clans",
                            "id": "#main/unified_processing/ncRNA_ribosomal_model_clans"
                        },
                        {
                            "source": "#main/ncRNA_ribosomal_models",
                            "id": "#main/unified_processing/ncRNA_ribosomal_models"
                        },
                        {
                            "source": "#main/sequencing_run_id",
                            "id": "#main/unified_processing/sequencing_run_id"
                        }
                    ],
                    "out": [
                        "#main/unified_processing/other_ncRNAs",
                        "#main/unified_processing/SSU_sequences",
                        "#main/unified_processing/LSU_sequences",
                        "#main/unified_processing/5S_sequences",
                        "#main/unified_processing/ssu_classifications",
                        "#main/unified_processing/predicted_CDS",
                        "#main/unified_processing/functional_annotations",
                        "#main/unified_processing/go_summary",
                        "#main/unified_processing/go_summary_slim",
                        "#main/unified_processing/qc_stats_summary",
                        "#main/unified_processing/qc_stats_seq_len_pcbin",
                        "#main/unified_processing/qc_stats_seq_len_bin",
                        "#main/unified_processing/qc_stats_seq_len",
                        "#main/unified_processing/qc_stats_nuc_dist",
                        "#main/unified_processing/qc_stats_gc_pcbin",
                        "#main/unified_processing/qc_stats_gc_bin",
                        "#main/unified_processing/qc_stats_gc",
                        "#main/unified_processing/match_count",
                        "#main/unified_processing/CDS_with_match_count",
                        "#main/unified_processing/reads_with_match_count",
                        "#main/unified_processing/stats_reads",
                        "#main/unified_processing/numberReadsWithOrf",
                        "#main/unified_processing/numberOrfs",
                        "#main/unified_processing/readsWithOrf",
                        "#main/unified_processing/interproscan",
                        "#main/unified_processing/no_functions_seqs",
                        "#main/unified_processing/pCDS_seqs"
                    ],
                    "id": "#main/unified_processing"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "functional analysis prediction with InterProScan",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#esl-reformat-replace.yaml/replace"
                        },
                        {
                            "$import": "#InterProScan-apps.yaml/apps"
                        },
                        {
                            "$import": "#InterProScan-protein_formats.yaml/protein_formats"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#functional_analysis.cwl/go_summary_config"
                },
                {
                    "type": "File",
                    "id": "#functional_analysis.cwl/predicted_CDS"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#functional_analysis.cwl/combine_annotations/result",
                    "id": "#functional_analysis.cwl/functional_annotations"
                },
                {
                    "type": "File",
                    "outputSource": "#functional_analysis.cwl/summarize_with_GO/go_summary",
                    "id": "#functional_analysis.cwl/go_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#functional_analysis.cwl/summarize_with_GO/go_summary_slim",
                    "id": "#functional_analysis.cwl/go_summary_slim"
                }
            ],
            "steps": [
                {
                    "run": "#fasta_chunker.cwl",
                    "in": [
                        {
                            "default": 10000,
                            "id": "#functional_analysis.cwl/chunk_inputs/chunk_size"
                        },
                        {
                            "source": "#functional_analysis.cwl/remove_asterisks_and_reformat/reformatted_sequences",
                            "id": "#functional_analysis.cwl/chunk_inputs/seqs"
                        }
                    ],
                    "out": [
                        "#functional_analysis.cwl/chunk_inputs/chunks"
                    ],
                    "id": "#functional_analysis.cwl/chunk_inputs"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#functional_analysis.cwl/functional_analysis/i5Annotations",
                            "id": "#functional_analysis.cwl/combine_annotations/files"
                        }
                    ],
                    "out": [
                        "#functional_analysis.cwl/combine_annotations/result"
                    ],
                    "id": "#functional_analysis.cwl/combine_annotations"
                },
                {
                    "doc": "Matches are generated against predicted CDS, using a sub set of databases\n(Pfam, TIGRFAM, PRINTS, PROSITE patterns, Gene3d) from InterPro. \n",
                    "run": "#InterProScan5.21-60.cwl",
                    "in": [
                        {
                            "default": [
                                "Pfam",
                                "TIGRFAM",
                                "PRINTS",
                                "ProSitePatterns",
                                "Gene3D"
                            ],
                            "id": "#functional_analysis.cwl/functional_analysis/applications"
                        },
                        {
                            "source": "#functional_analysis.cwl/chunk_inputs/chunks",
                            "id": "#functional_analysis.cwl/functional_analysis/proteinFile"
                        }
                    ],
                    "scatter": "#functional_analysis.cwl/functional_analysis/proteinFile",
                    "out": [
                        "#functional_analysis.cwl/functional_analysis/i5Annotations"
                    ],
                    "id": "#functional_analysis.cwl/functional_analysis"
                },
                {
                    "run": "#esl-reformat.cwl",
                    "in": [
                        {
                            "default": {
                                "find": "*",
                                "replace": "X"
                            },
                            "id": "#functional_analysis.cwl/remove_asterisks_and_reformat/replace"
                        },
                        {
                            "source": "#functional_analysis.cwl/predicted_CDS",
                            "id": "#functional_analysis.cwl/remove_asterisks_and_reformat/sequences"
                        }
                    ],
                    "out": [
                        "#functional_analysis.cwl/remove_asterisks_and_reformat/reformatted_sequences"
                    ],
                    "id": "#functional_analysis.cwl/remove_asterisks_and_reformat"
                },
                {
                    "doc": "A summary of Gene Ontology (GO) terms derived from InterPro matches to\nthe sample. It is generated using a reduced list of GO terms called\nGO slim (http://www.geneontology.org/ontology/subsets/goslim_metagenomics.obo)\n",
                    "run": "#go_summary.cwl",
                    "in": [
                        {
                            "source": "#functional_analysis.cwl/combine_annotations/result",
                            "id": "#functional_analysis.cwl/summarize_with_GO/InterProScan_results"
                        },
                        {
                            "source": "#functional_analysis.cwl/go_summary_config",
                            "id": "#functional_analysis.cwl/summarize_with_GO/config"
                        }
                    ],
                    "out": [
                        "#functional_analysis.cwl/summarize_with_GO/go_summary",
                        "#functional_analysis.cwl/summarize_with_GO/go_summary_slim"
                    ],
                    "id": "#functional_analysis.cwl/summarize_with_GO"
                }
            ],
            "id": "#functional_analysis.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "Find reads with predicted coding sequences above 60 AA in length",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "types": [
                        {
                            "$import": "#FragGeneScan-model.yaml/model"
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "id": "#orf_prediction.cwl/completeSeq"
                },
                {
                    "type": "#FragGeneScan-model.yaml/model",
                    "id": "#orf_prediction.cwl/model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#orf_prediction.cwl/sequence"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#orf_prediction.cwl/combine_predicted_CDS_aa/result",
                    "id": "#orf_prediction.cwl/predicted_CDS_aa"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#orf_prediction.cwl/combine_predicted_CDS_nuc/result",
                    "id": "#orf_prediction.cwl/predicted_CDS_nuc"
                }
            ],
            "steps": [
                {
                    "doc": "Find reads with predicted coding sequences (pCDS)\n",
                    "run": "#FragGeneScan1_20.cwl",
                    "in": [
                        {
                            "source": "#orf_prediction.cwl/completeSeq",
                            "id": "#orf_prediction.cwl/ORF_prediction/completeSeq"
                        },
                        {
                            "source": "#orf_prediction.cwl/model",
                            "id": "#orf_prediction.cwl/ORF_prediction/model"
                        },
                        {
                            "source": "#orf_prediction.cwl/split_seqs/chunks",
                            "id": "#orf_prediction.cwl/ORF_prediction/sequence"
                        }
                    ],
                    "scatter": "#orf_prediction.cwl/ORF_prediction/sequence",
                    "out": [
                        "#orf_prediction.cwl/ORF_prediction/predicted_CDS_aa",
                        "#orf_prediction.cwl/ORF_prediction/predicted_CDS_nuc"
                    ],
                    "id": "#orf_prediction.cwl/ORF_prediction"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#orf_prediction.cwl/ORF_prediction/predicted_CDS_aa",
                            "id": "#orf_prediction.cwl/combine_predicted_CDS_aa/files"
                        }
                    ],
                    "out": [
                        "#orf_prediction.cwl/combine_predicted_CDS_aa/result"
                    ],
                    "id": "#orf_prediction.cwl/combine_predicted_CDS_aa"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#orf_prediction.cwl/ORF_prediction/predicted_CDS_nuc",
                            "id": "#orf_prediction.cwl/combine_predicted_CDS_nuc/files"
                        }
                    ],
                    "out": [
                        "#orf_prediction.cwl/combine_predicted_CDS_nuc/result"
                    ],
                    "id": "#orf_prediction.cwl/combine_predicted_CDS_nuc"
                },
                {
                    "run": "#fasta_chunker.cwl",
                    "in": [
                        {
                            "default": 100000,
                            "id": "#orf_prediction.cwl/split_seqs/chunk_size"
                        },
                        {
                            "source": "#orf_prediction.cwl/sequence",
                            "id": "#orf_prediction.cwl/split_seqs/seqs"
                        }
                    ],
                    "out": [
                        "#orf_prediction.cwl/split_seqs/chunks"
                    ],
                    "id": "#orf_prediction.cwl/split_seqs"
                }
            ],
            "id": "#orf_prediction.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/docs/schema_org_rdfa.html",
        "http://edamontology.org/EDAM_1.16.owl"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
